# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: informaticsmatters/protobuf/datamanager/pod_event_message.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?informaticsmatters/protobuf/datamanager/pod_event_message.proto\x12\'informaticsmatters.protobuf.datamanager\"q\n\x0fPodEventMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\x1d\n\x15replace_prior_content\x18\x05 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'informaticsmatters.protobuf.datamanager.pod_event_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_PODEVENTMESSAGE']._serialized_start=108
  _globals['_PODEVENTMESSAGE']._serialized_end=221
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: informaticsmatters/protobuf/accountserver/merchant_processing_charge_message.proto
# Protobuf Python Version: 4.25.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRinformaticsmatters/protobuf/accountserver/merchant_processing_charge_message.proto\x12)informaticsmatters.protobuf.accountserver\"\x9d\x02\n\x1fMerchantProcessingChargeMessage\x12\x11\n\ttimestamp\x18\x01 \x01(\t\x12\x15\n\rmerchant_kind\x18\x02 \x01(\t\x12\x15\n\rmerchant_name\x18\x03 \x01(\t\x12\x13\n\x0bmerchant_id\x18\x04 \x01(\r\x12\x11\n\tauth_code\x18\x06 \x01(\r\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\r\n\x05\x63oins\x18\x08 \x01(\t\x12\x0b\n\x03sqn\x18\t \x01(\r\x12\x0b\n\x03\x65oc\x18\n \x01(\x08\x12\x0c\n\x04user\x18\x10 \x01(\t\x12\x0f\n\x07product\x18\x11 \x01(\t\x12\x0c\n\x04unit\x18\x12 \x01(\t\x12\x14\n\x0corganisation\x18\x13 \x01(\t\x12\x17\n\x0f\x61\x64\x64itional_data\x18\x1e \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'informaticsmatters.protobuf.accountserver.merchant_processing_charge_message_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_MERCHANTPROCESSINGCHARGEMESSAGE']._serialized_start=130
  _globals['_MERCHANTPROCESSINGCHARGEMESSAGE']._serialized_end=415
# @@protoc_insertion_point(module_scope)
